#################################################################################
#                                                                               #
#                       copyright (c) 2003 Ingeniweb SARL                       #
#                                                                               #
#################################################################################

"""MinimalContentType main class"""


from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
import string

from Products.CMFCore.CMFCorePermissions import View, ManageProperties, ListFolderContents
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore import CMFCorePermissions
from AccessControl import Permissions, getSecurityManager, ClassSecurityInfo, Unauthorized
from OFS import Folder

from global_symbols import *



# MinimalContentType definition
factory_type_information = {
  'id'             : 'MinimalContentType',
  'portal_type'    : 'MinimalContentType',
  'meta_type'      : 'Minimal Content Type',
  'description'    : 'A simple content type',
  'content_icon'   : 'MinimalContentType.gif',                          # Icon has to be acquired from a skin folder
  'product'        : 'PloneMinimalProduct',
  'factory'        : 'addMinimalContentType',
  'immediate_view' : 'MinimalContentType_edit',
  'filter_content_types' : 0,                                   # This is for folderish types
  'allowed_content_types': (),                                  # If filter_content_types is true, this field can hold allowed meta_types
  'actions': (
    {
    'id'           : 'view',
    'name'         : 'View',
    'action'       : 'MinimalContentType_view',
    'permissions'  : (CMFCorePermissions.View, ),
    'category'      : 'object',
    },
    {
    'id'           : 'edit',
    'name'         : 'Edit',
    'action'       : 'portal_form/MinimalContentType_editForm',
    'permissions'   : (CMFCorePermissions.ModifyPortalContent, ),
    'category'      : 'object',
    },
    {
    'id'            : 'metadata',
    'name'          : 'Metadata',
    'action'        : 'metadata_edit_form',
    'permissions'   : (CMFCorePermissions.ModifyPortalContent, ),
    'category'      : 'object',
    },
    ),
  }
  
# The usual factory
def addMinimalContentType(self, id, title = '', REQUEST = {}):
    """
    Factory method for a MinimalContentType object
    """
    obj = MinimalContentType(id, title)
    self._setObject(id, obj)

    if REQUEST.has_key('RESPONSE'):
        return REQUEST.RESPONSE.redirect('manage_main')



class MinimalContentType(PortalContent, DefaultDublinCoreImpl):
    """MinimalContentType class"""
    meta_type = factory_type_information['meta_type']                   # Has not to be the same as FTI but it is the most usual case.

    manage_options = PortalContent.manage_options

    text = ""           # Default text

    # Standard security settings
    security = ClassSecurityInfo()
    security.declareObjectProtected(CMFCorePermissions.View)            # $$$ Is this clever ? Isn't it better to make the object private ?


    # Init method
    def __init__(self, id, title=''):
        """__init__(self, id, title='')"""

        self.id = id
        self.title = title

    # Class-internal factory method
    security.declareProtected(MinimalContentType_addPermission, 'manage_addMinimalContentType')
    def manage_addMinimalContentType(self, id, title='', REQUEST=None):
        """ adds a new PloneFolder """
        ob=PloneFolder(id, title)
    	self._setObject(id, ob)
    	if REQUEST is not None:
            return self.folder_contents(self, REQUEST, portal_status_message='Added content.')


    # Edit method (change this to suit your needs)
    # This edit method should only change attributes that are neither 'id' or metadatas.
    security.declareProtected(MinimalContentType_editPermission, 'manage_editMinimalContentType')
    def manage_editMinimalContentType(self, title = '', text = '', REQUEST = {}):
        """
        manage_editMinimalContentType(self, title = '', text = '', REQUEST = {}) => object modification method
        """
        # Change attributes
        self.title = title
        self.text = text

        # Redirect
    	if REQUEST is not None:
            return self.folder_contents(self, REQUEST, portal_status_message='Updated content.')
        



manage_addMinimalContentType = MinimalContentType.manage_addMinimalContentType


# Class instanciation
InitializeClass(MinimalContentType)


