#################################################################################
#                                                                               #
#                       copyright (c) 2003 Ingeniweb SARL                       #
#                                                                               #
#################################################################################

"""MinimalFolderishType main class"""


from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
import string

from Products.CMFCore.CMFCorePermissions import View, ManageProperties, ListFolderContents
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore import CMFCorePermissions
from Products.CMFDefault import SkinnedFolder
from AccessControl import Permissions, getSecurityManager, ClassSecurityInfo, Unauthorized
from OFS import Folder

from global_symbols import *


# MinimalFolderishType definition
factory_type_information = {
  'id'             : 'MinimalFolderishType',
  'portal_type'    : 'MinimalFolderishType',
  'meta_type'      : 'Minimal Folderish Type',
  'description'    : 'A folderish type that does nothing',
  'content_icon'   : 'MinimalFolderishType.gif',                          # Icon has to be acquired from a skin folder
  'product'        : 'PloneMinimalProduct',
  'factory'        : 'addMinimalFolderishType',
  'immediate_view' : 'folder_listing',                          
  'filter_content_types' : 0,                                   # This is for folderish types
  'allowed_content_types': (),                                  # If filter_content_types is true, this field can hold allowed meta_types
  'actions': (
    {
    'id'           : 'view',
    'name'         : 'View',
    'action'       : 'MinimalFolderishType_view',
    'permissions'  : (CMFCorePermissions.View, ),
##    'category'      : 'folder',
    },
    {
    'id'            : 'folderlisting',
    'name'          : 'Folder Listing',
    'action'        : 'folder_listing',
    'permissions'   : (Permissions.access_contents_information,),
    'category'      : 'folder',
    },
    {
    'id'           : 'edit',
    'name'         : 'Edit',
    'action'       : 'portal_form/MinimalFolderishType_editForm',
    'permissions'  : (MinimalFolderishType_editPermission,),
##    'category'      : 'folder',
    },
  ),
  }

# The usual factory
def addMinimalFolderishType(self, id, title = '', REQUEST = {}):
    """
    Factory method for a MinimalFolderishType object
    """
    obj = MinimalFolderishType(id, title)
    self._setObject(id, obj)

    if REQUEST.has_key('RESPONSE'):
        return REQUEST.RESPONSE.redirect('manage_main')





class MinimalFolderishType(SkinnedFolder.SkinnedFolder, ):
    """MinimalFolderishType class"""
    meta_type = factory_type_information['meta_type']                   # Has not to be the same as FTI but it is the most usual case.

    manage_options = Folder.Folder.manage_options

    # Standard security settings
    security = ClassSecurityInfo()
    security.declareObjectProtected(CMFCorePermissions.View)            # $$$ Is this clever ? Isn't it better to make the object private ?


    # Dummy permission instanciation.
    # Permissions has to be "dummily" instanciated in order to be reachable for the factory_type_information structure.
    # In order to be very clear, we just declare each and every permission we use in this product.
    security.declareProtected(MinimalFolderishType_editPermission, "dummyMethod_editPermission")
    security.declareProtected(MinimalFolderishType_addPermission, "dummyMethod_addPermission")

    # Init method
    def __init__(self, id, title=''):
        """__init__(self, id, title='')"""

        self.id = id
        self.title = title

    # Class-internal factory method
    security.declareProtected(MinimalFolderishType_addPermission, 'manage_addMinimalFolderishType')
    def manage_addMinimalFolderishType(self, id, title='', REQUEST=None):
        """ adds a new PloneFolder """
        ob=PloneFolder(id, title)
    	self._setObject(id, ob)
    	if REQUEST is not None:
            return self.folder_contents(self, REQUEST, portal_status_message='Added folder.')

    # Edit method (change this to suit your needs)
    # This edit method should only change attributes that are neither 'id' or metadatas.
    security.declareProtected(MinimalFolderishType_editPermission, 'manage_editMinimalFolderishType')
    def manage_editMinimalFolderishType(self, title = '', REQUEST = {}):
        """
        manage_editMinimalFolderishType(self, title = '', REQUEST = {}) => object modification method
        """
        # Change title
        self.title = title
    	if REQUEST is not None:
            return self.folder_contents(self, REQUEST, portal_status_message='Updated folder.')
        


    # This method comes from PloneFolder class.
    security.declareProtected(Permissions.access_contents_information, 'listFolderContents')
    def listFolderContents( self, spec=None, contentFilter=None, suppressHiddenFiles=0 ): 
        """
        Hook around 'contentValues' to let 'folder_contents'
        be protected.  Duplicating skip_unauthorized behavior of dtml-in.
        
        In the world of Plone we do not want to show objects that begin with a .
        So we have added a simply check.  We probably dont want to raise an
        Exception as much as we want to not show it.
        
        """

        items = self.contentValues(spec=spec, filter=contentFilter)
        l = []
        for obj in items:
            id = obj.getId()
            v = obj
            try:
                if suppressHiddenFiles and id[:1]=='.': 
                    raise Unauthorized(id, v)
                if getSecurityManager().validate(self, self, id, v):
                    l.append(obj)
            except (Unauthorized, 'Unauthorized'):
                pass
        return l


manage_addMinimalFolderishType = MinimalFolderishType.manage_addMinimalFolderishType


# Class instanciation
InitializeClass(MinimalFolderishType)


